//LabPlot : PlotPie.h

#ifndef PLOTPIE_H
#define PLOTPIE_H

#include "Plot.h"

class PlotPie:public Plot {
public:
	PlotPie(Worksheet *p);
	~PlotPie() {}
	QStringList Info();
	Axis *getAxis(int) { return 0; }
	void saveAxes(QTextStream *) {}
	void openAxes(QTextStream *, int) {}
	void enableGrid(int, bool) {}
	bool gridEnabled(int) { return false; }
	void enableBorder(int, bool) {}
	bool borderEnabled(int) { return false; }
	void draw(QPainter* p,int w, int h);
	void drawCurves(QPainter* p, int w, int h);
/*	void drawAxes(QPainter* p,bool hide);*/
	void setBorder(int, bool) { }
	void setRange(LRange* r,int i) {range[i]=*r; }
	void setActRange(LRange* r,int i) {actrange[i]=*r; }
	void setRanges(LRange* r) {range[0]=r[0];range[1]=r[1];range[2]=r[2];}
	void setActRanges(LRange* r) {actrange[0]=r[0];actrange[1]=r[1];actrange[2]=r[2];}
private:
	//Axis axis[12];		// x, y, z, x2, y2, z2, x3, y3, z3, x4, y4, z4
	//bool borderenabled[12];	// x, y, z, x2, y2, z2, x3, y3, z3, x4, y4, z4
	//bool gridenabled[24];
	// x, xmin, y, ymin, z, zmin, x2, x2min, y2, y2min , z2, z2min,
	// x3, x3min, y3, y3min, z3, z3min, x4, x4min, y4, y4min, z4, z4min
};

#endif // PLOTPIE_H
